@@ -1,9 +1,11 @@
 package OpenTracing::WrapScope;
-our $VERSION = '0.100.0';
+our $VERSION = '0.101.0';
 use strict;
 use warnings;
+use warnings::register;
 use B::Hooks::EndOfScope;
 use OpenTracing::GlobalTracer;
+use PerlX::Maybe;
 use Sub::Info qw/sub_info/;
 
 {  # transparent caller, stolen from Hook::LexWrap
@@ -30,30 +32,48 @@ sub import {
     my $pkg = caller;
     on_scope_end {
         foreach my $sub (@subs) {
-            $sub = "${pkg}::$sub" if $sub !~ /'|::/;
-            die "Couldn't find sub: $sub" if not defined &$sub;
-
-            no strict 'refs';
-            no warnings 'redefine';
-            *$sub = wrapped(\&$sub);
+            install_wrapped(_qualify_sub($sub, $pkg));
         }
     };
     return;
 }
 
+sub install_wrapped {
+    my ($sub) = @_;
+    $sub = _qualify_sub($sub, scalar caller);
+
+    if (not defined &$sub) {
+        warnings::warn "Couldn't find sub: $sub";
+        return;
+    }
+
+    no strict 'refs';
+    no warnings 'redefine';
+    *$sub = wrapped(\&$sub);
+
+    return;
+}
 
 sub wrapped {
     my ($coderef) = @_;
     my $info = sub_info($coderef);
 
     return sub {
+        my ($call_package, $call_filename, $call_line) = caller(0);
+        my $call_sub = (caller(1))[3];
         my $tracer = OpenTracing::GlobalTracer->get_global_tracer; 
         my $scope = $tracer->start_active_span(
-            $info->{name},
+            "$info->{package}::$info->{name}",
             tags => {
-                package => $info->{package},
-                file    => $info->{file},
-                line    => $info->{start_line},
+                'source.subname' => $info->{name},
+                'source.file'    => $info->{file},
+                'source.line'    => $info->{start_line},
+                'source.package' => $info->{package},
+                maybe
+                'caller.subname' => $call_sub,
+                'caller.file'    => $call_filename,
+                'caller.line'    => $call_line,
+                'caller.package' => $call_package,
             },
         );
 
@@ -77,4 +97,10 @@ sub wrapped {
     };
 }
 
+sub _qualify_sub {
+    my ($sub, $pkg) = @_;
+    return $sub if $sub =~ /'|::/;
+    return "${pkg}::$sub";
+}
+
 1;
